==> ejc-bfyjerp-api-3.0.0-20250603.054212-223-sources.jar: com/ejianc/business/oa/vo/EmployeeSalaryVO.java <==
package com.ejianc.business.oa.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 人力行政-薪资异动审批表
 * 
 * @author generator
 * 
 */
public class EmployeeSalaryVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 编号
    private Long employeeId; // 员工名称
    private String name; // 员工名称
    private Long orgId; // 区域ID
    private String orgName; // 区域
    private Long deptId; // 部门ID
    private String deptName; // 部门
    private Long postId; // 岗位ID
    private String postName; // 岗位
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date intoDate; // 入职日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date useDate; // 生效日期
    private Integer rank; // 层级
    private String rankName; // 层级
    private Integer changeType; // 异动类别（1涨薪2降薪）
    private String changeTypeName; // 异动类别
    private BigDecimal changeSalary; // 异动金额
    private BigDecimal salary; // 薪资标准
    private BigDecimal basicSalary; // 原基本薪资
    private BigDecimal postSalary; // 原岗位薪资
    private BigDecimal levelSalary; // 原层级薪资
    private BigDecimal certSalary; // 证书津贴
    private BigDecimal baseCertSalary; //
    private BigDecimal educatedSalary; // 学历津贴
    private BigDecimal sportSalary; // 交通补助
    private BigDecimal yearSalary; // 司龄津贴
    private BigDecimal newSalary; // 异动后薪资标准
    private BigDecimal newBasicSalary; // 新基本薪资
    private BigDecimal newPostSalary; // 新岗位薪资
    private BigDecimal newLevelSalary; // 新层级薪资
    private String memo; // 异动原因
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中

    private String cert; // 证书情况
    private String certName; // 证书情况

    private String baseCert; // 证书情况
    private String baseCertName; // 证书情况
    private BigDecimal yearSalaryInit; // 司龄津贴初始值
    @JsonFormat(pattern = "yyyy-MM", timezone = "GMT+8")
    private Date yearChangeDate; // 司龄调整月份
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date formalDate; // 转正日期

    public Date getFormalDate() {
        return formalDate;
    }

    public void setFormalDate(Date formalDate) {
        this.formalDate = formalDate;
    }
    public Date getYearChangeDate() {
        return yearChangeDate;
    }

    public void setYearChangeDate(Date yearChangeDate) {
        this.yearChangeDate = yearChangeDate;
    }

    public BigDecimal getYearSalaryInit() {
        return yearSalaryInit;
    }

    public void setYearSalaryInit(BigDecimal yearSalaryInit) {
        this.yearSalaryInit = yearSalaryInit;
    }
    public String getBaseCert() {
        return baseCert;
    }

    public void setBaseCert(String baseCert) {
        this.baseCert = baseCert;
    }

    public String getBaseCertName() {
        return baseCertName;
    }

    public void setBaseCertName(String baseCertName) {
        this.baseCertName = baseCertName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public String getCert() {
        return cert;
    }
    @ReferDeserialTransfer
    public void setCert(String cert) {
        this.cert = cert;
    }

    public String getCertName() {
        return certName;
    }

    public void setCertName(String certName) {
        this.certName = certName;
    }

    public BigDecimal getBaseCertSalary() {
        return baseCertSalary;
    }

    public void setBaseCertSalary(BigDecimal baseCertSalary) {
        this.baseCertSalary = baseCertSalary;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode="bfyj-employee-info")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getDeptId() {
        return deptId;
    }
    @ReferDeserialTransfer
    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    @ReferSerialTransfer(referCode="idm_post")
    public Long getPostId() {
        return postId;
    }
    @ReferDeserialTransfer
    public void setPostId(Long postId) {
        this.postId = postId;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public Date getIntoDate() {
        return intoDate;
    }

    public void setIntoDate(Date intoDate) {
        this.intoDate = intoDate;
    }
    public Date getUseDate() {
        return useDate;
    }

    public void setUseDate(Date useDate) {
        this.useDate = useDate;
    }
    public Integer getRank() {
        return rank;
    }

    public void setRank(Integer rank) {
        this.rank = rank;
    }
    public String getRankName() {
        return rankName;
    }

    public void setRankName(String rankName) {
        this.rankName = rankName;
    }
    public Integer getChangeType() {
        return changeType;
    }

    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }
    public String getChangeTypeName() {
        return changeTypeName;
    }

    public void setChangeTypeName(String changeTypeName) {
        this.changeTypeName = changeTypeName;
    }
    public BigDecimal getChangeSalary() {
        return changeSalary;
    }

    public void setChangeSalary(BigDecimal changeSalary) {
        this.changeSalary = changeSalary;
    }
    public BigDecimal getSalary() {
        return salary;
    }

    public void setSalary(BigDecimal salary) {
        this.salary = salary;
    }
    public BigDecimal getBasicSalary() {
        return basicSalary;
    }

    public void setBasicSalary(BigDecimal basicSalary) {
        this.basicSalary = basicSalary;
    }
    public BigDecimal getPostSalary() {
        return postSalary;
    }

    public void setPostSalary(BigDecimal postSalary) {
        this.postSalary = postSalary;
    }
    public BigDecimal getLevelSalary() {
        return levelSalary;
    }

    public void setLevelSalary(BigDecimal levelSalary) {
        this.levelSalary = levelSalary;
    }
    public BigDecimal getCertSalary() {
        return certSalary;
    }

    public void setCertSalary(BigDecimal certSalary) {
        this.certSalary = certSalary;
    }
    public BigDecimal getEducatedSalary() {
        return educatedSalary;
    }

    public void setEducatedSalary(BigDecimal educatedSalary) {
        this.educatedSalary = educatedSalary;
    }
    public BigDecimal getSportSalary() {
        return sportSalary;
    }

    public void setSportSalary(BigDecimal sportSalary) {
        this.sportSalary = sportSalary;
    }
    public BigDecimal getYearSalary() {
        return yearSalary;
    }

    public void setYearSalary(BigDecimal yearSalary) {
        this.yearSalary = yearSalary;
    }
    public BigDecimal getNewSalary() {
        return newSalary;
    }

    public void setNewSalary(BigDecimal newSalary) {
        this.newSalary = newSalary;
    }
    public BigDecimal getNewBasicSalary() {
        return newBasicSalary;
    }

    public void setNewBasicSalary(BigDecimal newBasicSalary) {
        this.newBasicSalary = newBasicSalary;
    }
    public BigDecimal getNewPostSalary() {
        return newPostSalary;
    }

    public void setNewPostSalary(BigDecimal newPostSalary) {
        this.newPostSalary = newPostSalary;
    }
    public BigDecimal getNewLevelSalary() {
        return newLevelSalary;
    }

    public void setNewLevelSalary(BigDecimal newLevelSalary) {
        this.newLevelSalary = newLevelSalary;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
}

==> ejc-bfyjerp-api-3.0.0-20250919.071631-296-sources.jar: com/ejianc/business/oa/vo/EmployeeSalaryVO.java <==
package com.ejianc.business.oa.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 人力行政-薪资异动审批表
 * 
 * @author generator
 * 
 */
public class EmployeeSalaryVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 编号
    private Long employeeId; // 员工名称
    private String name; // 员工名称
    private Long orgId; // 区域ID
    private String orgName; // 区域
    private Long deptId; // 部门ID
    private String deptName; // 部门
    private Long postId; // 岗位ID
    private String postName; // 岗位
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date intoDate; // 入职日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date useDate; // 生效日期
    private Integer rank; // 层级
    private String rankName; // 层级
    private Integer changeType; // 异动类别（1涨薪2降薪）
    private String changeTypeName; // 异动类别
    private BigDecimal changeSalary; // 异动金额
    private BigDecimal salary; // 薪资标准
    private BigDecimal basicSalary; // 原基本薪资
    private BigDecimal postSalary; // 原岗位薪资
    private BigDecimal levelSalary; // 原层级薪资
    private BigDecimal certSalary; // 证书津贴
    private BigDecimal baseCertSalary; //
    private BigDecimal educatedSalary; // 学历津贴
    private BigDecimal sportSalary; // 交通补助
    private BigDecimal yearSalary; // 司龄津贴
    private BigDecimal newSalary; // 异动后薪资标准
    private BigDecimal newBasicSalary; // 新基本薪资
    private BigDecimal newPostSalary; // 新岗位薪资
    private BigDecimal newLevelSalary; // 新层级薪资
    private String memo; // 异动原因
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中

    private String cert; // 证书情况
    private String certName; // 证书情况

    private String baseCert; // 证书情况
    private String baseCertName; // 证书情况
    private BigDecimal yearSalaryInit; // 司龄津贴初始值
    @JsonFormat(pattern = "yyyy-MM", timezone = "GMT+8")
    private Date yearChangeDate; // 司龄调整月份
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date formalDate; // 转正日期
    private BigDecimal otherNeedPay; // 原其他应付
    private BigDecimal newOtherNeedPay; // 其他应付
    private BigDecimal newEducatedSalary; // 学历津贴
    private BigDecimal newSportSalary; // 交通补助

    public BigDecimal getOtherNeedPay() {
        return otherNeedPay;
    }

    public void setOtherNeedPay(BigDecimal otherNeedPay) {
        this.otherNeedPay = otherNeedPay;
    }

    public BigDecimal getNewOtherNeedPay() {
        return newOtherNeedPay;
    }

    public void setNewOtherNeedPay(BigDecimal newOtherNeedPay) {
        this.newOtherNeedPay = newOtherNeedPay;
    }

    public BigDecimal getNewEducatedSalary() {
        return newEducatedSalary;
    }

    public void setNewEducatedSalary(BigDecimal newEducatedSalary) {
        this.newEducatedSalary = newEducatedSalary;
    }

    public BigDecimal getNewSportSalary() {
        return newSportSalary;
    }

    public void setNewSportSalary(BigDecimal newSportSalary) {
        this.newSportSalary = newSportSalary;
    }

    public Date getFormalDate() {
        return formalDate;
    }

    public void setFormalDate(Date formalDate) {
        this.formalDate = formalDate;
    }
    public Date getYearChangeDate() {
        return yearChangeDate;
    }

    public void setYearChangeDate(Date yearChangeDate) {
        this.yearChangeDate = yearChangeDate;
    }

    public BigDecimal getYearSalaryInit() {
        return yearSalaryInit;
    }

    public void setYearSalaryInit(BigDecimal yearSalaryInit) {
        this.yearSalaryInit = yearSalaryInit;
    }
    public String getBaseCert() {
        return baseCert;
    }

    public void setBaseCert(String baseCert) {
        this.baseCert = baseCert;
    }

    public String getBaseCertName() {
        return baseCertName;
    }

    public void setBaseCertName(String baseCertName) {
        this.baseCertName = baseCertName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public String getCert() {
        return cert;
    }
    @ReferDeserialTransfer
    public void setCert(String cert) {
        this.cert = cert;
    }

    public String getCertName() {
        return certName;
    }

    public void setCertName(String certName) {
        this.certName = certName;
    }

    public BigDecimal getBaseCertSalary() {
        return baseCertSalary;
    }

    public void setBaseCertSalary(BigDecimal baseCertSalary) {
        this.baseCertSalary = baseCertSalary;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode="bfyj-employee-info")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getDeptId() {
        return deptId;
    }
    @ReferDeserialTransfer
    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    @ReferSerialTransfer(referCode="idm_post")
    public Long getPostId() {
        return postId;
    }
    @ReferDeserialTransfer
    public void setPostId(Long postId) {
        this.postId = postId;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public Date getIntoDate() {
        return intoDate;
    }

    public void setIntoDate(Date intoDate) {
        this.intoDate = intoDate;
    }
    public Date getUseDate() {
        return useDate;
    }

    public void setUseDate(Date useDate) {
        this.useDate = useDate;
    }
    public Integer getRank() {
        return rank;
    }

    public void setRank(Integer rank) {
        this.rank = rank;
    }
    public String getRankName() {
        return rankName;
    }

    public void setRankName(String rankName) {
        this.rankName = rankName;
    }
    public Integer getChangeType() {
        return changeType;
    }

    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }
    public String getChangeTypeName() {
        return changeTypeName;
    }

    public void setChangeTypeName(String changeTypeName) {
        this.changeTypeName = changeTypeName;
    }
    public BigDecimal getChangeSalary() {
        return changeSalary;
    }

    public void setChangeSalary(BigDecimal changeSalary) {
        this.changeSalary = changeSalary;
    }
    public BigDecimal getSalary() {
        return salary;
    }

    public void setSalary(BigDecimal salary) {
        this.salary = salary;
    }
    public BigDecimal getBasicSalary() {
        return basicSalary;
    }

    public void setBasicSalary(BigDecimal basicSalary) {
        this.basicSalary = basicSalary;
    }
    public BigDecimal getPostSalary() {
        return postSalary;
    }

    public void setPostSalary(BigDecimal postSalary) {
        this.postSalary = postSalary;
    }
    public BigDecimal getLevelSalary() {
        return levelSalary;
    }

    public void setLevelSalary(BigDecimal levelSalary) {
        this.levelSalary = levelSalary;
    }
    public BigDecimal getCertSalary() {
        return certSalary;
    }

    public void setCertSalary(BigDecimal certSalary) {
        this.certSalary = certSalary;
    }
    public BigDecimal getEducatedSalary() {
        return educatedSalary;
    }

    public void setEducatedSalary(BigDecimal educatedSalary) {
        this.educatedSalary = educatedSalary;
    }
    public BigDecimal getSportSalary() {
        return sportSalary;
    }

    public void setSportSalary(BigDecimal sportSalary) {
        this.sportSalary = sportSalary;
    }
    public BigDecimal getYearSalary() {
        return yearSalary;
    }

    public void setYearSalary(BigDecimal yearSalary) {
        this.yearSalary = yearSalary;
    }
    public BigDecimal getNewSalary() {
        return newSalary;
    }

    public void setNewSalary(BigDecimal newSalary) {
        this.newSalary = newSalary;
    }
    public BigDecimal getNewBasicSalary() {
        return newBasicSalary;
    }

    public void setNewBasicSalary(BigDecimal newBasicSalary) {
        this.newBasicSalary = newBasicSalary;
    }
    public BigDecimal getNewPostSalary() {
        return newPostSalary;
    }

    public void setNewPostSalary(BigDecimal newPostSalary) {
        this.newPostSalary = newPostSalary;
    }
    public BigDecimal getNewLevelSalary() {
        return newLevelSalary;
    }

    public void setNewLevelSalary(BigDecimal newLevelSalary) {
        this.newLevelSalary = newLevelSalary;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
}
